==> javie-0.5.2-src.tar.gz: javie-0.5.2-src/ch.kuramo.javie.app/src/main/java/ch/kuramo/mmd2javie/MMD2JavieHandler.java <==
/*
 * Copyright (c) 2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.mmd2javie;

import java.io.File;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.handlers.HandlerUtil;
import org.mozilla.javascript.ContextFactory;

import ch.kuramo.javie.app.InjectorHolder;
import ch.kuramo.javie.app.UIUtil;
import ch.kuramo.javie.app.project.NewLayerCompositionOperation;
import ch.kuramo.javie.app.project.ProjectManager;
import ch.kuramo.javie.app.views.ProjectView;
import ch.kuramo.javie.core.CompositionItem;
import ch.kuramo.javie.core.Folder;
import ch.kuramo.javie.core.Item;
import ch.kuramo.javie.core.LayerComposition;
import ch.kuramo.javie.core.Project;
import ch.kuramo.javie.core.services.ProjectElementFactory;

import com.google.inject.Inject;

public class MMD2JavieHandler extends AbstractHandler {

	@Inject
	private ProjectElementFactory elementFactory;

	@Inject
	private ContextFactory contextFactory;


	public MMD2JavieHandler() {
		InjectorHolder.getInjector().injectMembers(this);
	}

	public Object execute(ExecutionEvent event) throws ExecutionException {
		IWorkbenchWindow window = HandlerUtil.getActiveWorkbenchWindowChecked(event);

		ProjectManager pm = ProjectManager.forWorkbenchWindow(window);
		if (pm == null) {
			return null;
		}

		File file = showFileDialog(window);
		if (file == null) {
			return null;
		}

		Project project = null;
		try {
			project = elementFactory.newProject();

			ProgressMonitorDialog dialog = new ProgressMonitorDialog(window.getShell()) {
				protected int getShellStyle() {
					return super.getShellStyle() | SWT.SHEET;
				}
			};

			MMD2Javie mmd2javie = new MMD2Javie(contextFactory);
			if (mmd2javie.run(file, project, dialog)) {
				CompositionItem compItem = (CompositionItem) project.getItems().get(0);

				ProjectView projectView = UIUtil.showView(window.getActivePage(), ProjectView.ID);
				Folder parent = projectView.getItemTreeInsertionPoint();
				pm.postOperation(new NewLayerCompositionOperation(pm, parent,
						compItem.getName(), (LayerComposition)compItem.getComposition(), "MMD2AE JSXファイルの読み込み"));
			}

		} finally {
			if (project != null) {
				for (Item i : project.getItems()) {
					i.dispose();
				}
			}
		}

		return null;
	}

	private File showFileDialog(IWorkbenchWindow window) {
		String[] filterNames = new String[] { "JSXファイル (*.jsx)", "すべてのファイル" };
		String[] filterExtensions = new String[] { "*.jsx", "*" };

		String platform = SWT.getPlatform();
		if (platform.equals("win32") || platform.equals("wpf")) {
			filterExtensions[filterExtensions.length-1] = "*.*";
		}

		FileDialog dialog = new FileDialog(window.getShell(), SWT.OPEN | SWT.SHEET);
		dialog.setFilterNames(filterNames);
		dialog.setFilterExtensions(filterExtensions);

		if (dialog.open() == null) {
			return null;
		}

		return new File(dialog.getFilterPath(), dialog.getFileName());
	}

}

==> javie-0.5.9-20110806-src.tar.gz: javie-0.5.9-src/ch.kuramo.javie.app/src/main/java/ch/kuramo/mmd2javie/MMD2JavieHandler.java <==
/*
 * Copyright (c) 2010,2011 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.mmd2javie;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.handlers.HandlerUtil;
import org.mozilla.javascript.ContextFactory;

import ch.kuramo.javie.app.InjectorHolder;
import ch.kuramo.javie.app.UIUtil;
import ch.kuramo.javie.app.project.NewLayerCompositionOperation;
import ch.kuramo.javie.app.project.ProjectManager;
import ch.kuramo.javie.app.views.ProjectView;
import ch.kuramo.javie.core.CompositionItem;
import ch.kuramo.javie.core.Folder;
import ch.kuramo.javie.core.Item;
import ch.kuramo.javie.core.LayerComposition;
import ch.kuramo.javie.core.Project;
import ch.kuramo.javie.core.services.ProjectElementFactory;

import com.google.inject.Inject;

public class MMD2JavieHandler extends AbstractHandler {

	@Inject
	private ProjectElementFactory elementFactory;

	@Inject
	private ContextFactory contextFactory;


	public MMD2JavieHandler() {
		InjectorHolder.getInjector().injectMembers(this);
	}

	public Object execute(ExecutionEvent event) throws ExecutionException {
		IWorkbenchWindow window = HandlerUtil.getActiveWorkbenchWindowChecked(event);

		ProjectManager pm = ProjectManager.forWorkbenchWindow(window);
		if (pm == null) {
			return null;
		}

		File file = showFileDialog(window);
		if (file == null) {
			return null;
		}

		ProgressMonitorDialog progMonDialog = new ProgressMonitorDialog(window.getShell()) {
			protected int getShellStyle() {
				return super.getShellStyle() | SWT.SHEET;
			}
		};

		if (isVmdFile(file)) {
			MMD2Javie2 m2j2 = new MMD2Javie2();
			if (m2j2.readFile(file, progMonDialog)) {
				WizardDialog wizardDialog = new WizardDialog(window.getShell(), new MMD2Javie2Wizard(m2j2, pm));
				wizardDialog.open();
			} else {
				// TODO
				//String error = m2j2.getError();
				//if (error != null) {
				//	MessageDialog.openError(window.getShell(), "エラー", error);
				//}
			}
			return null;
		}

		Project project = null;
		try {
			project = elementFactory.newProject();

			MMD2Javie mmd2javie = new MMD2Javie(contextFactory);
			if (mmd2javie.run(file, project, progMonDialog)) {
				CompositionItem compItem = (CompositionItem) project.getItems().get(0);

				ProjectView projectView = UIUtil.showView(window.getActivePage(), ProjectView.ID);
				Folder parent = projectView.getItemTreeInsertionPoint();
				pm.postOperation(new NewLayerCompositionOperation(pm, parent,
						compItem.getName(), (LayerComposition)compItem.getComposition(), "MMD2AE JSXファイルの読み込み"));
			}

		} finally {
			if (project != null) {
				for (Item i : project.getItems()) {
					i.dispose();
				}
			}
		}

		return null;
	}

	private File showFileDialog(IWorkbenchWindow window) {
		String[] filterNames = new String[] { "VMDファイル (*.vmd)", "MMD2AE JSXファイル (*.jsx)", "すべてのファイル" };
		String[] filterExtensions = new String[] { "*.vmd", "*.jsx", "*" };

		String platform = SWT.getPlatform();
		if (platform.equals("win32") || platform.equals("wpf")) {
			filterExtensions[filterExtensions.length-1] = "*.*";
		}

		FileDialog dialog = new FileDialog(window.getShell(), SWT.OPEN | SWT.SHEET);
		dialog.setFilterNames(filterNames);
		dialog.setFilterExtensions(filterExtensions);

		if (dialog.open() == null) {
			return null;
		}

		return new File(dialog.getFilterPath(), dialog.getFileName());
	}

	private boolean isVmdFile(File file) throws ExecutionException {
		try {
			FileInputStream in = null;
			try {
				in = new FileInputStream(file);

				byte[] bytes = new byte[26];
				int len = in.read(bytes);
				if (bytes[len-1] != 0) return false;

				String str = new String(bytes, 0, len-1, "US-ASCII");
				return str.equals("Vocaloid Motion Data 0002");

			} finally {
				if (in != null) in.close();
			}
		} catch (IOException e) {
			throw new ExecutionException("error reading file: " + file.getName(), e);
		}
	}

}
